CastDevice class

Constructors

CastDevice({required String serviceName, required String name, required String host, required int port, Map<String, String> extras = const <String, String>{}})
const

Properties

extras → Map<String, String>
final
hashCode → int
The hash code for this object.
no setteroverride
host → String
final
name → String
friendly name
final
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceName → String
unique across network
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override