CastSession class

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageStream → Stream<Map<String, dynamic>>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String
final
socket → CastSocket
no setter
state → CastSessionState
no setter
stateStream → Stream<CastSessionState>
no setter

Methods

close() → Future
flush() → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage(String namespace, Map<String, dynamic> payload) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

connect(String sessionId, CastDevice device, [Duration? timeout]) → Future<CastSession>